@@ -8,14 +8,14 @@ from geospock_cli.exceptions import CLIError
 
 class MessageSender:
     @staticmethod
-    def parse_and_make_request(url: str, method: str, body: str, headers) -> dict:
+    def parse_and_make_request(url: str, method: str, body: str, headers) -> str:
         parsed_url = urlparse(url)
         response = MessageSender.make_request(parsed_url.netloc, parsed_url.path, method, body, headers,
                                               parsed_url.scheme == "https")
         return response
 
     @staticmethod
-    def make_request(endpoint: str, path: str, method: str, body: str, headers, ssl=True) -> dict:
+    def make_request(endpoint: str, path: str, method: str, body: str, headers, ssl=True) -> str:
         if ssl:
             conn = http.client.HTTPSConnection(endpoint)
         else:
